# https://mybinder.org/
# https://ericmjl.github.io/blog/2020/9/12/add-a-direct-binder-link-for-built-html-notebooks/
# https://mybinder.readthedocs.io/en/latest/examples/sample_repos.html#user-interfaces
# https://github.com/binder-examples/jupyterlab
# ref: Git ref (branch, tag, or commit)
# urlpath=lab/tree/ or labpath=
BINDER_BASE_BADGE: str = "[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/{owner}/{repo}/{ref}?labpath={notebook})"

# https://colab.research.google.com/github/googlecolab/colabtools/blob/master/notebooks/colab-github-demo.ipynb
# https://timsainburg.com/google%20colab.html
COLAB_BASE_BADGE: str = "[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/{owner}/{repo}/blob/{ref}/{notebook})"

# https://github.com/SuNaden/deepnote-launch-example
# https://docs.deepnote.com/collaboration/launch-repositories-in-deepnote
DEEPNOTE_BASE_BADGE: str = "[![Deepnote](https://deepnote.com/buttons/launch-in-deepnote-small.svg)](https://deepnote.com/launch?url={url})"



from urllib.parse import quote_plus

import click
import pyperclip
from giturlparse import parse

from .constants import BINDER_BASE_BADGE, COLAB_BASE_BADGE, DEEPNOTE_BASE_BADGE


# https://click.palletsprojects.com/en/8.1.x/setuptools/
@click.command()
# https://click.palletsprojects.com/en/8.1.x/quickstart/#adding-parameters
# https://click.palletsprojects.com/en/8.1.x/arguments/
@click.argument("url")
def main(url: str) -> None:
    """Generate Jupyter notebook badges for different services."""

    # https://github.com/nephila/giturlparse#exposed-attributes
    p = parse(url)
    ref, notebook = p.path.split("/", maxsplit=1)

    binder_badge = BINDER_BASE_BADGE.format(
        owner=p.owner, repo=p.repo, ref=ref, notebook=notebook
    )
    colab_badge = COLAB_BASE_BADGE.format(
        owner=p.owner, repo=p.repo, ref=ref, notebook=notebook
    )
    deepnote_badge = DEEPNOTE_BASE_BADGE.format(url=quote_plus(url))

    all_badges = " ".join([binder_badge, colab_badge, deepnote_badge])

    click.secho("Badges:", bold=True)
    click.echo(all_badges)
    pyperclip.copy(all_badges)

    click.echo("\n📋 Copied!")
